HydroLM - A Pyhton package for linear regressions for Hydrology
===================================================================

The HydroLM package contains a class and functions for automating linear regressions OLS for hydrologists.

.. Documentation
.. --------------
.. The primary documentation for the package can be found `here <http://eto.readthedocs.io>`_.

Installation
------------
ETo can be installed via pip or conda::

  pip install hydrolm

or::

  conda install -c mullenkamp hydrolm

The core dependency is `Pandas <http://pandas.pydata.org/pandas-docs/stable/>`_ and `statsmodels <https://www.statsmodels.org/stable/index.html>`_.
